#
# spec file for package upplay
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           upplay
Version:        1.7.3
Release:        1.2
Summary:        UPnP and OpenHome audio Control Point
License:        GPL-2.0-or-later
URL:            https://www.lesbonscomptes.com/upplay/
Source0:        https://www.lesbonscomptes.com/upplay/downloads/upplay-%{version}.tar.gz
Source1:        https://www.lesbonscomptes.com/upplay/downloads/upplay-%{version}.tar.gz.asc
Source2:        https://www.lesbonscomptes.com/pages/jf-at-dockes.org.pub#/%{name}.keyring
Patch0:         use-webengine.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-qtbase-common-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5WebEngine)
BuildRequires:  pkgconfig(jsoncpp)
BuildRequires:  pkgconfig(libupnpp) >= 0.24.1
BuildRequires:  pkgconfig(mpris-qt5)

%description
upplay is a Qt5-based audio Control Point for browsing and playing music
managed by your UPnP/DLNA media servers to your UPnP/DLNA/OpenHome players (renderers).

%prep
%autosetup -p0

%build
%qmake5 QMAKE_POST_LINK='$(STRIP) $(TARGET)'
%make_build STRIP=%{_bindir}/strip

%install
make install INSTALL_ROOT=%{buildroot}
%suse_update_desktop_file -n -r %{name} "AudioVideo;Player"
%fdupes %{buildroot}/%{_prefix}

%files
%license COPYING
%doc AUTHORS
%{_bindir}/%{name}
%{_datadir}/applications/upplay.desktop
%{_datadir}/%{name}
%{_datadir}/icons/hicolor/48x48/apps/upplay.png
%{_datadir}/pixmaps/upplay.png

%changelog
* Fri May 17 2024 Michael Pujos <pujos.michael@gmail.com>
- update to 1.7.3
  * Allow loading a bare URL.
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Sat Dec 23 2023 Michael Pujos <pujos.michael@gmail.com>
- added use-webengine.patch to force use of Qt5WebEngine
- update to 1.7.2
  * Unicast search the last used renderer at startup (depending on lib version).
- update to 1.7.1
  * Add preference to use libupnpp extra URL quoting which is now non-default.
- update to 1.7.0
  * Avoid most ways that a stuck renderer could freeze the GUI.
  * Windows: hopefully full support for keyboard traversal and screen
    readers.
  * Add menu for playlist mode settings (repeat, shuffle etc.). These were
    not accessible with a keyboard otherwise.
  * Fix playlist drag and drop: drag to first position is now possible.
  * Avoid phantom track appearing in the playlist when connecting to
    stopped upmpdcli in UPnP/AV mode
  * Misc improvements and fixes.
- update to 1.6.5
  * Disabled non-functional last.FM interface (last.FM changed their
    authentication method to something which would be complicated to support)
- update to 1.6.4
  * Fix potential crash when removing tracks from UPnP/AV playlist
* Sat Aug 13 2022 Michael Pujos <pujos.michael@gmail.com>
- add upstream signing key and validate source signature
- update to 1.6.3
  * Fix dir browser display in cases (search string overlapping first result entry)
  * Avoid having to restart after changing lower lib log level
- update to 1.6.2
  * Fix playlist drag and drop
- update to 1.6.1
  * New alternative tabbed compact interface for small displays
  * Hopefully better scaling
* Fri Apr 22 2022 Michael Pujos <pujos.michael@gmail.com>
- update to 1.6.0
  * New alternative tabbed compact interface for small displays
  * Hopefully better scaling
- update to 1.5.2
  * Implement minimal MPRIS interface on Linux, mostly so that
    media keys work on the Gnome desktop
  * Small miscellaneous improvements in directory browser display
  * Cache album covers
  * Option to poll for volume changes, for renderers which generate no volume events
* Thu Apr 15 2021 Michael Pujos <pujos.michael@gmail.com>
- update to 1.4.10
  * Make the renderer selection dialog dynamic: it will react to a
    renderer appearing on the network
  * When the connection with a renderer is lost, try to reconnect
    instead of asking the user what to do
  * Improve device restart detection and renew subscriptions when needed
  * Small fixes in colors in system dark theme
  * Small fixes in Webengine version
- removed dark-theme-fix.patch and browser-back-mouse-button-support.patch
  now in upstream
* Mon Nov 30 2020 Michael Pujos <pujos.michael@gmail.com>
- update to 1.4.7
  * Fix "close to tray" not working on Linux KDE
  * Clean up exit when tray is not available
  * Compilation warnings
- added dark-theme-fix.patch
- added browser-back-mouse-button-support.patch
- remove duplicates icons with fdupes
* Sun Nov 15 2020 Michael Pujos <pujos.michael@gmail.com>
- update to upstream version 1.4.6
